Welcome to Snakecdysis documentation!
=====================================


.. image:: ./_images/snakecdysis_logo.png
   :target: ./_images/snakecdysis_logo.png
   :alt: Snakecdysis Logo


.. automodule:: snakecdysis
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

About this package
------------------

Snakecdysis offers a straightforward and user-friendly solution for encapsulating your Snakemake workflow, transforming it into a robust bioinformatics tool. Combined with Snakecdysis, your Snakemake workflow is converted into a Python package that can be effortlessly installed and executed on both clusters and laptops. The package generated by Snakecdysis effectively offers a diverse set of tools and functionalities designed for both developers and users.

.. automodule:: snakecdysis
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

.. toctree::
   :caption: Installation
   :name: install
   :maxdepth: 5

   ./install
   ./package


.. toctree::
   :caption: Package documentation
   :name: module
   :maxdepth: 6

   ./snakecdysis
   ./workflow

.. toctree::
   :caption: Useful functions
   :name: useful
   :maxdepth: 4

   ./usefulfunctions

.. toctree::
   :caption: API
   :name: api_culebront
   :maxdepth: 2

   click.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
